<?php

/**
 * Hoa
 *
 *
 * @license
 *
 * New BSD License
 *
 * Copyright © 2007-2017, Hoa community. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Hoa nor the names of its contributors may be
 *       used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS AND CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

namespace Hoa\Socket;

/**
 * Class \Hoa\Socket\Node.
 *
 * Represent a generic node.
 *
 * @copyright  Copyright © 2007-2017 Hoa community
 * @license    New BSD License
 */
class Node
{
    /**
     * Node's ID.
     *
     * @var string
     */
    protected $_id             = null;

    /**
     * Node's socket resource.
     *
     * @var resource
     */
    private $_socket           = null;

    /**
     * Get server.
     *
     * @var \Hoa\Socket\Connection
     */
    private $_connection       = null;

    /**
     * Encryption type.
     *
     * @var int
     */
    protected $_encryptionType = null;



    /**
     * Constructor.
     *
     * @param   string                  $id            ID.
     * @param   resource                $socket        Socket.
     * @param   \Hoa\Socket\Connection  $connection    Connection.
     */
    public function __construct($id, $socket, Connection $connection)
    {
        $this->_id         = $id;
        $this->_socket     = $socket;
        $this->_connection = $connection;

        return;
    }

    /**
     * Get node's ID.
     *
     * @return  string
     */
    public function getId()
    {
        return $this->_id;
    }

    /**
     * Get node's socket resource.
     *
     * @return  resource
     */
    public function getSocket()
    {
        return $this->_socket;
    }

    /**
     * Get connection.
     *
     * @return  \Hoa\Socket\Connection
     */
    public function getConnection()
    {
        return $this->_connection;
    }

    /**
     * Set encryption type.
     *
     * @param   int  $type    Type of encryption (please, see ENCRYPTION_*
     *                        constants from Hoa\Socket\Client and
     *                        Hoa\Socket\Server).
     * @return  int
     */
    public function setEncryptionType($type)
    {
        $old                   = $this->_encryptionType;
        $this->_encryptionType = $type;

        return $old;
    }

    /**
     * Get encryption type.
     *
     * @return  int
     */
    public function getEncryptionType()
    {
        return $this->_encryptionType;
    }
}
